# x4xl

## A simple tool to ease import/export operation to and from Excel

x4xl is simple toolset that wraps an import/export workflow from excel into Pandas Dataframe objects and vice-versa.
It is composed of two main routines:
```
loadExcelSheet(file, sheet, parsef)

saveExcelSheet(file, sheet, parsef)
```

x4d3sign @ 2023